@@ -1,5 +1,5 @@
 from .typetwo import TypeTwo
-from .rowkey import RowKey
+from .rowkey import RowKey, NoKey
 from .dictcomparer import DictComparer
 from .isojson import IsoJson
 from .transformer import Transformer
@@ -7,6 +7,7 @@ from .transformer import Transformer
 __all__ = [
     TypeTwo.__name__, 
     RowKey.__name__, 
+    NoKey.__name__, 
     DictComparer.__name__, 
     IsoJson.__name__, 
     Transformer.__name__
